@@ -31,7 +31,7 @@ import textwrap
 import tokenize
 
 
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 
 
 try:
@@ -163,6 +163,10 @@ def format_docstring(indentation, docstring,
     if contents.count('"""'):
         return docstring
 
+    # Do not modify things that start with doctests.
+    if contents.lstrip().startswith('>>>'):
+        return docstring
+
     summary, description = split_summary_and_description(contents)
 
     if description:
@@ -290,8 +294,8 @@ def wrap_description(text, indentation, wrap_length):
     and bulleted lists alone.
 
     """
-    # Do modify doctests at all.
-    if '>' in text:
+    # Do not modify doctests at all.
+    if '>>>' in text:
         return text
 
     text = '\n'.join([indent_non_indented(l, indentation).rstrip()
